@@ -1,4 +1,4 @@
-/* $Id: tftp.c,v 1.6 2001/08/10 18:25:08 hpa Exp $ */
+/* $Id: tftp.c,v 1.8 2001/11/12 23:27:48 hpa Exp $ */
 
 /* $OpenBSD: tftp.c,v 1.4 1997/08/06 06:43:45 deraadt Exp $	*/
 /* $NetBSD: tftp.c,v 1.5 1995/04/29 05:55:25 cgd Exp $	*/
@@ -42,7 +42,7 @@
 /* static char sccsid[] = "@(#)tftp.c	8.1 (Berkeley) 6/6/93"; */
 /* static char rcsid[] = "$OpenBSD: tftp.c,v 1.4 1997/08/06 06:43:45 deraadt Exp $"; */
 static const char *rcsid UNUSED =
-"tftp-hpa $Id: tftp.c,v 1.6 2001/08/10 18:25:08 hpa Exp $";
+"tftp-hpa $Id: tftp.c,v 1.8 2001/11/12 23:27:48 hpa Exp $";
 #endif /* not lint */
 
 /* Many bug fixes are from Jim Guyton <guyton@rand-unix> */
@@ -65,19 +65,8 @@ static const char *rcsid UNUSED =
 #include <string.h>
 #include <unistd.h>
 
-#include "../config.h"
 #include "extern.h"
 
-#ifdef HAVE_STRINGS_H
-#include <strings.h>
-#endif
-
-#ifndef HAVE_SIGSETJMP
-#define sigsetjmp(x,y)  setjmp(x)
-#define siglongjmp(x,y) longjmp(x,y)
-#define sigjmp_buf jmp_buf
-#endif
-
 extern  struct sockaddr_in peeraddr;	/* filled in by main */
 extern  int     f;			/* the opened socket */
 extern  int     trace;
@@ -110,7 +99,7 @@ static void tpacket(const char *, struct tftphdr *, int);
  * Send the requested file.
  */
 void
-sendfile(int fd, char *name, char *mode)
+tftp_sendfile(int fd, char *name, char *mode)
 {
 	struct tftphdr *ap;	   /* data and ack packets */
 	struct tftphdr *dp;
@@ -212,7 +201,7 @@ abort:
  * Receive a file.
  */
 void
-recvfile(int fd, char *name, char *mode)
+tftp_recvfile(int fd, char *name, char *mode)
 {
 	struct tftphdr *ap;
 	struct tftphdr *dp;
