@@ -1,4 +1,4 @@
-/* $Id: misc.c,v 1.1 2001/07/20 06:59:54 hpa Exp $ */
+/* $Id: misc.c,v 1.2 2001/11/12 10:03:04 hpa Exp $ */
 /* ----------------------------------------------------------------------- *
  *   
  *   Copyright 2001 H. Peter Anvin - All Rights Reserved
@@ -15,9 +15,9 @@
  * Minor help routines.
  */
 
+#include "config.h"		/* Must be included first! */
 #include <syslog.h>
 #include <signal.h>
-#include <string.h>
 #include "tftpd.h"
 
 /*
